@@ -11,11 +11,25 @@ identical5 <- function(a,b,c,d,e) identical(a,b) && identical4(b,c,d,e)
 ## Make sure errors are signaled
 assertError <- function(expr) {
     d.expr <- deparse(substitute(expr))
-    t.res <- try(expr, silent = TRUE)
-    if(!inherits(t.res, "try-error"))
+    t.res <- tryCatch(expr, error = function(e) e)
+    if(!inherits(t.res, "error"))
 	stop(d.expr, "\n\t did not give an error", call. = FALSE)
     invisible(t.res)
 }
+assertWarningAtLeast <- function(expr) {
+    d.expr <- deparse(substitute(expr))
+    t.res <- tryCatch(expr, error = function(e)e, warning = function(w)w)
+    if(!inherits(t.res, "error") && !inherits(t.res, "warning"))
+	stop(d.expr, "\n\t did not give an error or warning", call. = FALSE)
+    invisible(t.res)
+}
+assertWarning <- function(expr) {
+    d.expr <- deparse(substitute(expr))
+    t.res <- tryCatch(expr, warning = function(w)w)
+    if(!inherits(t.res, "warning"))
+	stop(d.expr, "\n\t did not give a warning", call. = FALSE)
+    invisible(t.res)
+}
 
 isValid <- function(x, class) validObject(x, test=TRUE) && is(x, class)
 
@@ -36,6 +50,18 @@ all.slot.equal <- function(x,y, ...) {
     TRUE
 }
 
+## all.equal() for list-coercible objects -- apart from *some* components
+all.equal.X <- function(x,y, except, ...)
+{
+    .trunc <- function(x) {
+	ll <- as.list(x)
+	ll[ - match(except, names(ll), nomatch = 0L)]
+    }
+    all.equal(.trunc(x), .trunc(y), ...)
+}
+## e.g. in lme4:
+##  all.equal.X(env(m1), env(m2), except = c("call", "frame"))
+
 ## The relative error typically returned by all.equal:
 relErr <- function(target, current) { ## make this work for 'Matrix'
     ## ==> no mean() ..
@@ -48,15 +74,33 @@ relErr <- function(target, current) { ## make this work for 'Matrix'
 ## is.R22 <- (paste(R.version$major, R.version$minor, sep=".") >= "2.2")
 
 pkgRversion <- function(pkgname)
-    substring(packageDescription(pkgname)[["Built"]], 3,5)
+    sub("^R ([0-9.]+).*", "\\1", packageDescription(pkgname)[["Built"]])
+
+showProc.time <- local({ ## function + 'pct' variable
+    pct <- proc.time()
+    function(final="\n") { ## CPU elapsed __since last called__
+	ot <- pct ; pct <<- proc.time()
+	## 'Time ..' *not* to be translated:  tools::Rdiff() skips its lines!
+	cat('Time elapsed: ', (pct - ot)[1:3], final)
+    }
+})
+
+##' @title turn an S4 object (with slots) into a list with corresponding components
+##' @param obj an R object with a formal class (aka "S4")
+##' @return a list with named components where \code{obj} had slots
+##' @author Martin Maechler
+S4_2list <- function(obj) {
+   sn <- slotNames(obj)
+   structure(lapply(sn, slot, object = obj), .Names = sn)
+}
 
 
 ### ------- Part II  -- related to matrices, but *not* "Matrix" -----------
 
 add.simpleDimnames <- function(m) {
     stopifnot(length(d <- dim(m)) == 2)
-    dimnames(m) <- list(paste0("r", seq_len(d[1])),
-                        paste0("c", seq_len(d[2])))
+    dimnames(m) <- list(if(d[1]) paste0("r", seq_len(d[1])),
+                        if(d[2]) paste0("c", seq_len(d[2])))
     m
 }
 
@@ -83,6 +127,10 @@ assert.EQ.mat <- function(M, m, tol = if(show) 0 else 1e-15, show=FALSE) {
     else if(!isTRUE(r <- all.equal(MM, m, tol = tol)))
 	stop("all.equal() |->  ", r)
 }
+## a short cut
+assert.EQ.Mat <- function(M, M2, tol = if(show) 0 else 1e-15, show=FALSE)
+    assert.EQ.mat(M, as.mat(M2), tol=tol, show=show)
+
 
 chk.matrix <- function(M) {
     ## check object; including coercion to "matrix" :
@@ -120,6 +168,25 @@ asD <- function(m) { ## as "Dense"
 ## "normal" sparse Matrix: Csparse, no diag="U"
 asCsp <- function(x) Matrix:::diagU2N(as(x, "CsparseMatrix"))
 
+isNull.dimnames <- function(dn) {
+    is.null(dn) || {
+	dn <- unname(dn)
+	ch0 <- character(0)
+	identical(dn, list(NULL,NULL)) ||
+	identical(dn, list(ch0, NULL)) ||
+	identical(dn, list(NULL, ch0)) ||
+	identical(dn, list(ch0, ch0))
+    }
+}
+
+Qidentical.DN <- function(dx, dy) {
+    ## quasi-identical dimnames
+    stopifnot(is.list(dx) || is.null(dx),
+	      is.list(dy) || is.null(dy))
+    ## "empty"
+    (isNull.dimnames(dx) && isNull.dimnames(dy)) || identical(dx, dy)
+}
+
 Qidentical <- function(x,y, strictClass = TRUE) {
     ## quasi-identical - for 'Matrix' matrices
     if(class(x) != class(y)) {
@@ -128,6 +195,11 @@ Qidentical <- function(x,y, strictClass = TRUE) {
         ## else try further
     }
     slts <- slotNames(x)
+    if("Dimnames" %in% slts) { ## always (or we have no 'Matrix')
+	slts <- slts[slts != "Dimnames"]
+	if(!(Qidentical.DN(x@Dimnames, y@Dimnames)))
+	    return(FALSE)
+    }
     if("factors" %in% slts) { ## allow one empty and one non-empty 'factors'
         slts <- slts[slts != "factors"]
         ## if both are not empty, they must be the same:
@@ -140,11 +212,91 @@ Qidentical <- function(x,y, strictClass = TRUE) {
     TRUE
 }
 
-Q.C.identical <- function(x,y, sparse = is(x,"sparseMatrix")) {
-    if(sparse) Qidentical(as(x,"CsparseMatrix"), as(y,"CsparseMatrix"))
-    else Qidentical(x,y)
+Q.C.identical <- function(x,y, sparse = is(x,"sparseMatrix"),
+                          checkClass = TRUE, strictClass = TRUE) {
+    if(checkClass && class(x) != class(y)) {
+        if(strictClass || !is(x, class(y)))
+	   return(FALSE) ## else try further
+    }
+    if(sparse)
+	Qidentical(as(x,"CsparseMatrix"), as(y,"CsparseMatrix"),
+		   strictClass=strictClass)
+    else Qidentical(x,y, strictClass=strictClass)
 }
 
+##' <description>
+##'
+##' <details>
+##' @title  Quasi-equal for  'Matrix' matrices
+##' @param x  Matrix
+##' @param y  Matrix
+##' @param superclasses   x and y must coincide in (not) extending these
+##' @param dimnames.check  logical indicating if dimnames(.) much match
+##' @param tol  NA (--> use "==") or numerical tolerance for all.equal()
+##' @return   logical:  Are x and y (quasi) equal ?
+Q.eq <- function(x, y,
+		 superclasses =
+		 c("sparseMatrix", "denseMatrix",
+		   "dMatrix", "lMatrix", "nMatrix"),
+		 dimnames.check = TRUE, tol = NA) {
+    ## quasi-equal - for 'Matrix' matrices
+    if(any(dim(x) != dim(y)))
+	return(FALSE)
+    if(dimnames.check &&
+       !identical(dimnames(x),
+		  dimnames(y))) return(FALSE)
+    xcl <- getClassDef(class(x))
+    ycl <- getClassDef(class(y))
+    for(SC in superclasses) {
+	if( extends(xcl, SC) &&
+	   !extends(ycl, SC)) return(FALSE)
+    }
+    asC <- ## asCommon
+        if((isDense <- extends(xcl,"denseMatrix")))
+            function(m) as(m, "matrix")
+        else function(m)
+            as(as(as(m,"CsparseMatrix"), "dMatrix"), "dgCMatrix")
+    if(is.na(tol)) {
+	if(isDense)
+	    all(x == y | (is.na(x) & is.na(y)))
+	else ## 'x == y' blows up for large sparse matrices:
+	    isTRUE(all.equal(asC(x), asC(y), tol = 0.,
+			     check.attributes = dimnames.check))
+    }
+    else if(is.numeric(tol) && tol >= 0) {
+        isTRUE(all.equal(asC(x), asC(y), tol = tol,
+                         check.attributes = dimnames.check))
+    }
+    else stop("'tol' must be NA or non-negative number")
+}
+
+Q.eq2 <- function(x, y,
+		  superclasses = c("sparseMatrix", "denseMatrix"),
+		  dimnames.check = FALSE, tol = NA)
+    Q.eq(x,y, superclasses=superclasses,
+         dimnames.check=dimnames.check, tol=tol)
+
+##' <description>
+##'
+##' <details>
+##' @title  Quasi-equality of  symmpart(m) + skewpart(m) with m
+##' @param m  Matrix
+##' @param tol  numerical tolerance for all.equal()
+##' @return logical
+##' @author Martin Maechler
+Q.eq.symmpart <- function(m, tol = 8 * .Machine$double.eps)
+{
+    ss <- symmpart(m) + skewpart(m)
+    if(hasNA <- any(iNA <- is.na(ss))) {
+	## ss has the NA's symmetrically, but typically m has *not*
+	iiNA <- which(iNA) # <- useful! -- this tests  which() methods!
+	## assign NA's too -- using correct kind of NA:
+	m[iiNA] <- as(NA, Matrix:::.type.kind[Matrix:::.M.kind(m)])
+    }
+    Q.eq2(m, ss, tol = tol)
+}
+
+
 ## Useful Matrix constructors for testing:
 
 rspMat <- function(n, m = n, density = 1/4, nnz = round(density * n*m))
@@ -187,7 +339,7 @@ rUnitTri <- function(n, upper = TRUE, ...)
 
 ## This is related to rUnitTri(), ver
 mkLDL <- function(n, density = 1/3) {
-    ## Purpose: make nice artifical   A = L D L'  (with exact numbers) decomp
+    ## Purpose: make nice artificial   A = L D L'  (with exact numbers) decomp
     ## ----------------------------------------------------------------------
     ## Author: Martin Maechler, Date: 15 Mar 2008
     stopifnot(n == round(n))
@@ -205,7 +357,7 @@ mkLDL <- function(n, density = 1/3) {
     list(A = A, L = L, d.half = d.half, D = D)
 }
 
-eqDeterminant <- function(m1, m2, ...) {
+eqDeterminant <- function(m1, m2, NA.Inf.ok=FALSE, ...) {
     d1 <- determinant(m1) ## logarithm = TRUE
     d2 <- determinant(m2)
     d1m <- as.vector(d1$modulus)# dropping attribute
@@ -215,6 +367,10 @@ eqDeterminant <- function(m1, m2, ...) {
        (is.na(d1m) && is.na(d2m)))
 	## if both are NaN or NA, we "declare" that's fine here
 	return(TRUE)
+    else if(NA.Inf.ok && ## first can be NA, second infinite:
+            ## wanted: base::determinant.matrix() sometimes gives -Inf instead
+            ## of NA,e.g. for matrix(c(0,NA,0,0,NA,NA,0,NA,0,0,1,0,0,NA,0,1), 4,4))
+            is.na(d1m) && is.infinite(d2m)) return(TRUE)
     ## else
     if(is.infinite(d1m)) d1$modulus <- sign(d1m)* .Machine$double.xmax
     if(is.infinite(d2m)) d2$modulus <- sign(d2m)* .Machine$double.xmax
@@ -278,29 +434,50 @@ allCholesky <- function(A, verbose = FALSE, silentTry = FALSE)
 }
 
 
-##--- Compatibility tests "Matrix" =!= "traditional Matrix" ---
+###----- Checking a "Matrix" -----------------------------------------
+
+##' <description>
+##'
+##' <details>
+##' @title Compatibility tests "Matrix" <-> "traditional matrix"
+##'        and many more consistency checks
+##'
+##' @param m   a "Matrix"
+##' @param m.m as(m, "matrix")  {if 'do.matrix' }
+##' @param do.matrix logical indicating if as(m, "matrix") should be applied;
+##'    typically false for large sparse matrices
+##' @param do.t  logical: is t(m) "feasible" ?
+##' @param doNorm
+##' @param doOps
+##' @param doSummary
+##' @param doCoerce
+##' @param doCoerce2
+##' @param do.prod
+##' @param verbose logical indicating if "progress output" is produced.
+##' @param catFUN (when 'verbose' is TRUE): function to be used as generalized cat()
+##' @return TRUE (invisibly), unless an error is signalled
+##' @author Martin Maechler, since 11 Apr 2008
 checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
-			do.matrix = !(isSparse || isDiag) || prod(dim(m)) < 1e6,
+			do.matrix = !isSparse || prod(dim(m)) < 1e6,
 			do.t = TRUE, doNorm = TRUE, doOps = TRUE,
                         doSummary = TRUE, doCoerce = TRUE,
 			doCoerce2 = doCoerce && !extends(cld, "RsparseMatrix"),
+			do.prod = do.t && do.matrix && !extends(cld, "RsparseMatrix"),
 			verbose = TRUE, catFUN = cat)
 {
-    ## Purpose: Compatibility tests "Matrix" <-> "traditional matrix"
-    ## ----------------------------------------------------------------------
-    ## Arguments: m: is(., "Matrix")
-    ## ----------------------------------------------------------------------
-    ## Author: Martin Maechler, Date: 11 Apr 2008; building on tests originally
-    ##	       in dotestMat()  ../tests/Class+Meth.R
+    ## is also called from  dotestMat()  in ../tests/Class+Meth.R
+
     stopifnot(is(m, "Matrix"))
-    validObject(m)
+    validObject(m) # or error(....)
 
     clNam <- class(m)
     cld <- getClassDef(clNam) ## extends(cld, FOO) is faster than is(m, FOO)
     isCor    <- extends(cld, "corMatrix")
-    isSparse <- extends(cld, "sparseMatrix")
+    isSparse <- extends(cld, "sparseMatrix") # also true for diagonalMatrix !
     isSym    <- extends(cld, "symmetricMatrix")
     isDiag   <- extends(cld, "diagonalMatrix")
+    isPerm   <- extends(cld, "pMatrix")
+    is.n     <- extends(cld, "nMatrix")
     nonMatr  <- clNam != Matrix:::MatrixClass(clNam, cld)
 
     Cat	 <- function(...) if(verbose) cat(...)
@@ -314,6 +491,7 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 	dimnames(x) <- list(NULL,NULL)
 	x
     }
+    eps16 <- 16 * .Machine$double.eps
 
     ina <- is.na(m)
     if(do.matrix) {
@@ -341,6 +519,18 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 	    stopifnot(nonMatr || class(ttm) == clNam,
                       all(m == ttm | ina))
         ## else : not testing
+
+	## crossprod()	%*%  etc
+	if(do.prod) {
+	    c.m <-  crossprod(m)
+	    tcm <- tcrossprod(m)
+            tolQ <- if(isSparse) NA else eps16
+	    stopifnot(dim(c.m) == rep.int(ncol(m), 2),
+		      dim(tcm) == rep.int(nrow(m), 2),
+		      ## FIXME: %*% drops dimnames
+		      Q.eq2(c.m, tm %*% m, tol = tolQ),
+		      Q.eq2(tcm, m %*% tm, tol = tolQ))
+	}
     }
     if(!do.matrix) {
 	CatF(" will *not* coerce to 'matrix' since do.matrix is FALSE\n")
@@ -374,11 +564,10 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
     ## and test 'dim()' as well:
     d <- dim(m)
     isSqr <- d[1] == d[2]
-    isPerm <- extends(cld, "pMatrix")
     if(do.t) stopifnot(identical(diag(m), diag(t(m))))
     ## TODO: also === diag(band(m,0,0))
 
-    if(prod(d) < .Machine$integer.max) {
+    if(prod(d) < .Machine$integer.max && !extends(cld, "modelMatrix")) {
 	vm <- vec(m)
 	stopifnot(is(vm, "Matrix"), validObject(vm), dim(vm) == c(d[1]*d[2], 1))
     }
@@ -413,7 +602,7 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 	    stopifnot(Qidentical(as(m11, "generalMatrix"),
 				 as(m12, "generalMatrix")))
     }
-    if(isSparse && !extends(cld,"nMatrix")) {
+    if(isSparse && !is.n) {
 	## ensure that as(., "nMatrix") gives nz-pattern
 	CatF("as(., \"nMatrix\") giving full nonzero-pattern: ")
 	n1 <- as(m, "nMatrix")
@@ -457,11 +646,13 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 	    if(do.matrix) {
 		## determinant(<dense>) "fails" for triangular with NA such as
 		## (m <- matrix(c(1:0,NA,1), 2))
-		CatF("det...(): ")
+		CatF("symmpart(m) + skewpart(m) == m: ")
+		Q.eq.symmpart(m)
+		CatF("ok;  determinant(): ")
 		if(any(is.na(m.m)) && extends(cld, "triangularMatrix"))
 		    Cat(" skipped: is triang. and has NA")
 		else
-		    stopifnot(eqDeterminant(m, m.m))
+		    stopifnot(eqDeterminant(m, m.m, NA.Inf.ok=TRUE))
 		Cat("ok\n")
 	    }
 	} else assertError(determinant(m))
@@ -476,9 +667,10 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 
     if(doCoerce2 && do.matrix) { ## not for large m:  !m will be dense
 
-	if(extends(cld, "nMatrix")) {
+	if(is.n) {
 	    stopifnot(identical(m, as(as(m, "dMatrix"),"nMatrix")),
-		      identical(m, as(as(m, "lMatrix"),"nMatrix")))
+		      identical(m, as(as(m, "lMatrix"),"nMatrix")),
+		      identical(which(m), which(m.m)))
 	}
 	else if(extends(cld, "lMatrix")) { ## should fulfill even with NA:
 	    stopifnot(all(m | !m | ina), !any(!m & m & !ina))
@@ -493,7 +685,8 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 	    stopifnot(identical(m. , as(as(m. , "dMatrix"),"lMatrix")),
 		      clNam == "ldiMatrix" || # <- there's no "ndiMatrix"
 		      ## coercion to n* and back: only identical when no extra 0s:
-		      identical(m1., as(as(m1., "nMatrix"),"lMatrix")))
+		      identical(m1., as(as(m1., "nMatrix"),"lMatrix")),
+		      identical(which(m), which(m.m)))
 	}
 	else if(extends(cld, "dMatrix")) {
 	    m. <- if(isSparse && has0) n0m else m
@@ -505,15 +698,18 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 	    m1. <- m1 # replace NA by 1 in m1. , carefully not changing class:
 	    if(any(ina)) m1.@x[is.na(m1.@x)] <- 1
 	    ## coercion to n* (nz-pattern!) and back: only identical when no extra 0s and no NAs:
-	    stopifnot(Q.C.identical(m1., as(as(m., "nMatrix"),"dMatrix"), isSparse),
-		      Q.C.identical(m1 , as(as(m., "lMatrix"),"dMatrix"), isSparse))
+	    stopifnot(Q.C.identical(m1., as(as(m., "nMatrix"),"dMatrix"),
+				    isSparse, checkClass = FALSE),
+		      Q.C.identical(m1 , as(as(m., "lMatrix"),"dMatrix"),
+				    isSparse, checkClass = FALSE))
 	}
 
 	if(extends(cld, "triangularMatrix")) {
 	    mm. <- m
 	    i0 <- if(m@uplo == "L")
 		upper.tri(mm.) else lower.tri(mm.)
-	    mm.[i0] <- 0 # ideally, mm. remained triangular, but can be dge*
+	    n.catchWarn <- if(is.n) suppressWarnings else identity
+	    n.catchWarn( mm.[i0] <- 0 ) # ideally, mm. remained triangular, but can be dge*
 	    CatF("as(<triangular (ge)matrix>, ",clNam,"): ", sep='')
 	    tm <- as(as(mm., "triangularMatrix"), clNam)
 	    Cat("valid:", validObject(tm), "\n")
@@ -521,7 +717,7 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 		## note that diagU2N(<dtr>) |-> dtC :
 		stopifnot(Qidentical(tm, as(Matrix:::diagU2N(m), clNam)))
 	}
-	else if(extends(cld, "diagonalMatrix")) {
+	else if(isDiag) {
 
 	    ## TODO
 
@@ -529,7 +725,15 @@ checkMatrix <- function(m, m.m = if(do.matrix) as(m, "matrix"),
 
 	    ## TODO
 	}
+    }# end {doCoerce2 && ..}
+
+    if(doCoerce && isSparse) { ## coerce to sparseVector and back :
+	v <- as(m, "sparseVector")
+	stopifnot(length(v) == prod(d))
+	dim(v) <- d
+	stopifnot(Q.eq2(m, v))
     }
+
     invisible(TRUE)
 }
 
