@@ -336,23 +336,33 @@ void gcopy(drawing d, drawing d2, rect r)
     BitBlt(dc, r.x, r.y, r.width, r.height, sdc, r.x, r.y, SRCCOPY);
 }
 
-/* FIXME: could allow per-pixel alpha */
 void gcopyalpha(drawing d, drawing d2, rect r, int alpha) 
 {
     if(alpha <= 0) return;
     {
-	HDC dc = GETHDC(d), sdc = GETHDC(d2);
 	BLENDFUNCTION bl;
 	bl.BlendOp = AC_SRC_OVER;
 	bl.BlendFlags = 0;
 	bl.SourceConstantAlpha = alpha;
 	bl.AlphaFormat = 0;
-        AlphaBlend(dc, r.x, r.y, r.width, r.height,
-		   sdc, r.x, r.y, r.width, r.height,
-		   bl);
+        AlphaBlend(GETHDC(d), r.x, r.y, r.width, r.height,
+		   GETHDC(d2), r.x, r.y, r.width, r.height, bl);
     }
 }
 
+void gcopyalpha2(drawing d, image src, rect r) 
+{
+    BLENDFUNCTION bl;
+    bl.BlendOp = AC_SRC_OVER;
+    bl.BlendFlags = 0;
+    bl.SourceConstantAlpha = 255; /* per-pixel alpha only */
+    bl.AlphaFormat = AC_SRC_ALPHA;
+    bitmap bm = imagetobitmap(src);
+    AlphaBlend(GETHDC(d), r.x, r.y, r.width, r.height,
+	       GETHDC(bm), 0, 0, r.width, r.height, bl);
+    del(bm);
+}
+
 void gdrawellipse(drawing d, int width, rgb border, rect r, int fast,
 		  int lend, int ljoin, float lmitre)
 {
