@@ -86,7 +86,7 @@ getExportedValue <- function(ns, name) {
     ns <- tryCatch(asNamespace(pkg), hasNoNamespaceError = function(e) NULL)
     if (is.null(ns)) {
         pos <- match(paste("package", pkg, sep=":"), search(), 0L)
-        if (pos == 0)
+        if (pos == 0L)
             stop(gettextf("package %s has no name space and is not on the search path", sQuote(pkg)), domain = NA)
         get(name, pos = pos, inherits = FALSE)
     }
@@ -426,6 +426,13 @@ loadNamespace <- function (package, lib.loc = NULL,
 
         for (p in nsInfo$exportPatterns)
             exports <- c(ls(env, pattern = p, all.names = TRUE), exports)
+        ## certain things should never be exported.
+        if (length(exports)) {
+            stoplist <- c(".__NAMESPACE__.", ".__S3MethodsTable__.",
+                          ".packageName", ".First.lib", ".onLoad",
+                          ".onAttach", ".conflicts.OK", ".noGenerics")
+            exports <- exports[! exports %in% stoplist]
+        }
         ##
         if(.isMethodsDispatchOn() && methods:::.hasS4MetaData(ns) &&
            !identical(package, "methods") ) {
@@ -667,7 +674,14 @@ namespaceImportFrom <- function(self, ns, vars, generics, packages)
         self <- getNamespace(self)
     ns <- asNamespace(ns)
     nsname <- getNamespaceName(ns)
-    impvars <- if (missing(vars)) getNamespaceExports(ns) else vars
+    impvars <- if (missing(vars)) {
+        ## certain things should never be imported
+        stoplist <- c(".__NAMESPACE__.", ".__S3MethodsTable__.",
+                      ".packageName", ".First.lib", ".Last.lib",
+                      ".onLoad", ".onAttach", ".conflicts.OK", ".noGenerics")
+        vars <- getNamespaceExports(ns)
+        vars <- vars[! vars %in% stoplist]
+    } else vars
     impvars <- makeImportExportNames(impvars)
     impnames <- names(impvars)
     if (anyDuplicated(impnames)) {
@@ -1163,7 +1177,7 @@ registerS3method <- function(genname, class, method, envir = parent.frame()) {
 registerS3methods <- function(info, package, env)
 {
     n <- NROW(info)
-    if(n == 0) return()
+    if(n == 0L) return()
 
     assignWrapped <- function(x, method, home, envir) {
 	method <- method            # force evaluation
