@@ -370,31 +370,31 @@ pdf <- function(file = ifelse(onefile, "Rplots.pdf", "Rplot%03d.pdf"),
 }
 
 .ps.prolog <- c(
-"/gs  { gsave } def",
-"/gr  { grestore } def",
-"/ep  { showpage gr gr } def",
-"/m   { moveto } def",
-"/l  { rlineto } def",
-"/np  { newpath } def",
-"/cp  { closepath } def",
-"/f   { fill } def",
-"/o   { stroke } def",
-"/c   { newpath 0 360 arc } def",
-"/r   { 4 2 roll moveto 1 copy 3 -1 roll exch 0 exch rlineto 0 rlineto -1 mul 0 exch rlineto closepath } def",
-"/p1  { stroke } def",
-"/p2  { gsave bg fill grestore newpath } def",
-"/p3  { gsave bg fill grestore stroke } def",
-"/p6  { gsave bg eofill grestore newpath } def",
-"/p7  { gsave bg eofill grestore stroke } def",
+"/gs  { gsave } bind def",
+"/gr  { grestore } bind def",
+"/ep  { showpage gr gr } bind def",
+"/m   { moveto } bind def",
+"/l  { rlineto } bind def",
+"/np  { newpath } bind def",
+"/cp  { closepath } bind def",
+"/f   { fill } bind def",
+"/o   { stroke } bind def",
+"/c   { newpath 0 360 arc } bind def",
+"/r   { 4 2 roll moveto 1 copy 3 -1 roll exch 0 exch rlineto 0 rlineto -1 mul 0 exch rlineto closepath } bind def",
+"/p1  { stroke } bind def",
+"/p2  { gsave bg fill grestore newpath } bind def",
+"/p3  { gsave bg fill grestore stroke } bind def",
+"/p6  { gsave bg eofill grestore newpath } bind def",
+"/p7  { gsave bg eofill grestore stroke } bind def",
 "/t   { 5 -2 roll moveto gsave rotate",
 "       1 index stringwidth pop",
-"       mul neg 0 rmoveto show grestore } def",
-"/ta  { 4 -2 roll moveto gsave rotate show } def",
-"/tb  { 2 -1 roll 0 rmoveto show } def",
+"       mul neg 0 rmoveto show grestore } bind def",
+"/ta  { 4 -2 roll moveto gsave rotate show } bind def",
+"/tb  { 2 -1 roll 0 rmoveto show } bind def",
 "/cl  { grestore gsave newpath 3 index 3 index moveto 1 index",
 "       4 -1 roll lineto  exch 1 index lineto lineto",
-"       closepath clip newpath } def",
-"/srgb { [ /CIEBasedABC",
+"       closepath clip newpath } bind def",
+"/sRGB { [ /CIEBasedABC",
 "          << /DecodeLMN",
 "               [ { dup 0.03928 le",
 "                        {12.92321 div}",
@@ -407,9 +407,8 @@ pdf <- function(file = ifelse(onefile, "Rplots.pdf", "Rplot%03d.pdf"),
 "                         0.180437 0.072175 0.950301]",
 "             /WhitePoint [0.9505 1.0 1.0890]",
 "           >>",
-"         ] setcolorspace } def",
-"/setrgb { srgb setcolor } def",
-"/s   { scalefont setfont } def")
+"         ] setcolorspace } bind def",
+"/s   { scalefont setfont } bind def")
 
 ####################
 # PostScript font database
@@ -676,7 +675,7 @@ assign(".PDF.Options",
          useDingbats = TRUE,
          useKerning = TRUE,
          fillOddEven = FALSE,
-         maxRasters = 64), envir = .PSenv)
+         maxRasters = 1000L), envir = .PSenv)
 assign(".PDF.Options.default",
        get(".PDF.Options", envir = .PSenv),
        envir = .PSenv)
