@@ -23,11 +23,11 @@ rug <- function(x, ticksize = 0.03, side = 1, lwd = 0.5, col = par("fg"),
     if(!quiet) {
 	u <- par("usr")
 	u <- if (side %% 2 == 1) {
-	    if(par("xlog")) 10^u[1:2] else u[1:2]
+	    if(par("xlog")) 10^u[1L:2] else u[1L:2]
 	} else {
 	    if(par("ylog")) 10^u[3:4] else u[3:4]
 	}
-	if(any(x < u[1] | x > u[2]))
+	if(any(x < u[1L] | x > u[2L]))
 	    warning("some values will be clipped")
     }
     Axis(side = side, at = x, labels = FALSE,
