@@ -25,32 +25,32 @@ biplot.default <-
     n <- nrow(x)
     p <- nrow(y)
     if(missing(xlabs)) {
-	xlabs <- dimnames(x)[[1]]
-	if(is.null(xlabs)) xlabs <- 1:n
+	xlabs <- dimnames(x)[[1L]]
+	if(is.null(xlabs)) xlabs <- 1L:n
     }
     xlabs <- as.character(xlabs)
-    dimnames(x) <- list(xlabs, dimnames(x)[[2]])
+    dimnames(x) <- list(xlabs, dimnames(x)[[2L]])
     if(missing(ylabs)) {
-	ylabs <- dimnames(y)[[1]]
-	if(is.null(ylabs)) ylabs <- paste("Var", 1:p)
+	ylabs <- dimnames(y)[[1L]]
+	if(is.null(ylabs)) ylabs <- paste("Var", 1L:p)
     }
     ylabs <- as.character(ylabs)
-    dimnames(y) <- list(ylabs, dimnames(y)[[2]])
+    dimnames(y) <- list(ylabs, dimnames(y)[[2L]])
 
-    if(length(cex) == 1) cex <- c(cex, cex)
+    if(length(cex) == 1L) cex <- c(cex, cex)
     if(missing(col)) {
 	col <- par("col")
-	if (!is.numeric(col)) col <- match(col, palette(), nomatch=1)
-	col <- c(col, col + 1)
+	if (!is.numeric(col)) col <- match(col, palette(), nomatch=1L)
+	col <- c(col, col + 1L)
     }
-    else if(length(col) == 1) col <- c(col, col)
+    else if(length(col) == 1L) col <- c(col, col)
 
     unsigned.range <- function(x)
         c(-abs(min(x, na.rm=TRUE)), abs(max(x, na.rm=TRUE)))
-    rangx1 <- unsigned.range(x[, 1])
-    rangx2 <- unsigned.range(x[, 2])
-    rangy1 <- unsigned.range(y[, 1])
-    rangy2 <- unsigned.range(y[, 2])
+    rangx1 <- unsigned.range(x[, 1L])
+    rangx2 <- unsigned.range(x[, 2L])
+    rangy1 <- unsigned.range(y[, 1L])
+    rangy2 <- unsigned.range(y[, 2L])
 
     if(missing(xlim) && missing(ylim))
 	xlim <- ylim <- rangx1 <- rangx2 <- range(rangx1, rangx2)
@@ -61,24 +61,24 @@ biplot.default <-
     op <- par(pty = "s")
     if(!is.null(main))
         op <- c(op, par(mar = par("mar")+c(0,0,1,0)))
-    plot(x, type = "n", xlim = xlim, ylim = ylim, col = col[1],
+    plot(x, type = "n", xlim = xlim, ylim = ylim, col = col[1L],
          xlab = xlab, ylab = ylab, sub = sub, main = main, ...)
-    text(x, xlabs, cex = cex[1], col = col[1], ...)
+    text(x, xlabs, cex = cex[1L], col = col[1L], ...)
     par(new = TRUE)
     plot(y, axes = FALSE, type = "n", xlim = xlim*ratio, ylim = ylim*ratio,
-	 xlab = "", ylab = "", col = col[1], ...)
-    axis(3, col = col[2], ...)
-    axis(4, col = col[2], ...)
-    box(col = col[1])
-    text(y, labels=ylabs, cex = cex[2], col = col[2], ...)
+	 xlab = "", ylab = "", col = col[1L], ...)
+    axis(3, col = col[2L], ...)
+    axis(4, col = col[2L], ...)
+    box(col = col[1L])
+    text(y, labels=ylabs, cex = cex[2L], col = col[2L], ...)
     if(var.axes)
-	arrows(0, 0, y[,1] * 0.8, y[,2] * 0.8, col = col[2], length=arrow.len)
+	arrows(0, 0, y[,1L] * 0.8, y[,2L] * 0.8, col = col[2L], length=arrow.len)
     invisible()
 }
 
-biplot.princomp <- function(x, choices = 1:2, scale = 1, pc.biplot=FALSE, ...)
+biplot.princomp <- function(x, choices = 1L:2L, scale = 1, pc.biplot=FALSE, ...)
 {
-    if(length(choices) != 2) stop("length of choices must be 2")
+    if(length(choices) != 2L) stop("length of choices must be 2")
     if(!length(scores <- x$scores))
 	stop(gettextf("object '%s' has no scores", deparse(substitute(x))),
              domain = NA)
@@ -93,9 +93,9 @@ biplot.princomp <- function(x, choices = 1:2, scale = 1, pc.biplot=FALSE, ...)
     invisible()
 }
 
-biplot.prcomp <- function(x, choices = 1:2, scale = 1, pc.biplot=FALSE, ...)
+biplot.prcomp <- function(x, choices = 1L:2L, scale = 1, pc.biplot=FALSE, ...)
 {
-    if(length(choices) != 2) stop("length of choices must be 2")
+    if(length(choices) != 2L) stop("length of choices must be 2")
     if(!length(scores <- x$x))
 	stop(gettextf("object '%s' has no scores", deparse(substitute(x))),
              domain = NA)
