@@ -67,13 +67,16 @@ formula.character <- function(x, env = parent.frame(), ...)
     ff
 }
 
-print.formula <- function(x, ...) {
+print.formula <- function(x, showEnv = !identical(e, .GlobalEnv), ...)
+{
+    e <- environment(.x <- x) ## return(.) original x
     attr(x, ".Environment") <- NULL
     print.default(unclass(x), ...)
-    invisible(x)
+    if (showEnv) print(e)
+    invisible(.x)
 }
 
-"[.formula" <- function(x,i) {
+`[.formula` <- function(x,i) {
     ans <- NextMethod("[")
     ## as.character gives a vector.
     if(as.character(ans[[1L]])[1L] == "~") {
@@ -98,8 +101,10 @@ as.formula <- function(object, env = parent.frame())
 terms <- function(x, ...) UseMethod("terms")
 terms.default <- function(x, ...) {
     v <- x$terms
-    if(is.null(v))
-        stop("no terms component")
+    if(is.null(v)) {
+        v <- attr(x, "terms")
+        if(is.null(v)) stop("no terms component nor attribute")
+    }
     v
 }
 
@@ -136,7 +141,7 @@ delete.response <- function (termobj)
     termobj
 }
 
-reformulate <- function (termlabels, response=NULL)
+reformulate <- function (termlabels, response=NULL, intercept = TRUE)
 {
     if(!is.character(termlabels) || !length(termlabels))
         stop("'termlabels' must be a character vector of length at least one")
@@ -144,6 +149,7 @@ reformulate <- function (termlabels, response=NULL)
     termtext <- paste(if(has.resp) "response", "~",
 		      paste(termlabels, collapse = "+"),
 		      collapse = "")
+    if(!intercept) termtext <- paste(termtext, "- 1")
     rval <- eval(parse(text = termtext)[[1L]])
     if(has.resp) rval[[2L]] <-
         if(is.character(response)) as.symbol(response) else response
@@ -160,19 +166,20 @@ drop.terms <- function(termobj, dropx = NULL, keep.response = FALSE)
         if(!inherits(termobj, "terms"))
             stop("'termobj' must be a object of class \"terms\"")
 	newformula <- reformulate(attr(termobj, "term.labels")[-dropx],
-				  if (keep.response) termobj[[2L]] else NULL)
+				  if (keep.response) termobj[[2L]] else NULL,
+                                  attr(termobj, "intercept"))
         environment(newformula) <- environment(termobj)
 	terms(newformula, specials=names(attr(termobj, "specials")))
     }
 }
 
 
-"[.terms" <-function (termobj, i)
+`[.terms` <-function (termobj, i)
 {
     resp <- if (attr(termobj, "response")) termobj[[2L]] else NULL
     newformula <- attr(termobj, "term.labels")[i]
     if (length(newformula) == 0L) newformula <- "1"
-    newformula <- reformulate(newformula, resp)
+    newformula <- reformulate(newformula, resp, attr(termobj, "intercept"))
     environment(newformula)<-environment(termobj)
     terms(newformula, specials = names(attr(termobj, "specials")))
 }
@@ -245,6 +252,12 @@ anova <- function(object, ...)UseMethod("anova")
 effects <- function(object, ...)UseMethod("effects")
 
 weights <- function(object, ...)UseMethod("weights")
+## used for class "lm", e.g. in drop1.
+weights.default <- function(object, ...)
+{
+    wts <-  object$weights
+    if (is.null(wts)) wts else napredict(object$na.action, wts)
+}
 
 df.residual <- function(object, ...)UseMethod("df.residual")
 df.residual.default <- function(object, ...) object$df.residual
@@ -367,9 +380,13 @@ model.frame.default <-
     vars <- attr(formula, "variables")
     predvars <- attr(formula, "predvars")
     if(is.null(predvars)) predvars <- vars
-    varnames <- sapply(vars, deparse, width.cutoff=500)[-1L]
+    ## Some people have generated longer variable names
+    ## https://stat.ethz.ch/pipermail/r-devel/2010-October/058756.html
+    varnames <- sapply(vars, function(x) paste(deparse(x,width.cutoff=500),
+                                               collapse=' '))[-1L]
     variables <- eval(predvars, data, env)
-    if(is.null(rownames) && (resp <- attr(formula, "response")) > 0L) {
+    resp <- attr(formula, "response")
+    if(is.null(rownames) && resp > 0L) {
         ## see if we can get rownames from the response
         lhs <- variables[[resp]]
         rownames <- if(is.matrix(lhs)) rownames(lhs) else names(lhs)
@@ -413,14 +430,14 @@ model.frame.default <-
 			stop(gettextf("factor '%s' has new level(s) %s",
                                       nm, paste(nxl[m], collapse=", ")),
                              domain = NA)
-		    data[[nm]] <- factor(xi, levels=xl)
+		    data[[nm]] <- factor(xi, levels=xl, exclude=NULL)
 		}
 	    }
     } else if(drop.unused.levels) {
 	for(nm in names(data)) {
 	    x <- data[[nm]]
 	    if(is.factor(x) &&
-	       length(unique(x)) < length(levels(x)))
+	       length(unique(x[!is.na(x)])) < length(levels(x)))
 		data[[nm]] <- data[[nm]][, drop = TRUE]
 	}
     }
