@@ -555,7 +555,7 @@ function(pkgdir, outfile, title, batch = FALSE,
     Usage <- function() {
         cat("Usage: R CMD Rd2dvi [options] files",
             "",
-            "Generate DVI (or PDF) output from the Rd sources specified by files, by",
+            "Generate PDF (or DVI) output from the Rd sources specified by files, by",
             "either giving the paths to the files, or the path to a directory with",
             "the sources of a package, or an installed package.",
             "",
@@ -578,7 +578,8 @@ function(pkgdir, outfile, title, batch = FALSE,
             "      --no-clean	do not remove created temporary files",
             "      --no-preview	do not preview generated DVI/PDF file",
             "      --encoding=enc    use 'enc' as the default input encoding",
-            "      --outputEncoding=outenc use 'outenc' as the default output encoding",
+            "      --outputEncoding=outenc",
+            "                        use 'outenc' as the default output encoding",
             "      --os=NAME		use OS subdir 'NAME' (unix or windows)",
             "      --OS=NAME		the same as '--os'",
             "  -o, --output=FILE	write output to FILE",
@@ -590,8 +591,8 @@ function(pkgdir, outfile, title, batch = FALSE,
             "      --internals	typeset 'internal' documentation (usually skipped)",
             "",
             "The output papersize is set by the environment variable R_PAPERSIZE.",
-            "The DVI previewer is set by the environment variable xdvi.",
             "The PDF previewer is set by the environment variable R_PDFVIEWER.",
+            "The DVI previewer is set by the environment variable xdvi.",
             "",
             "Report bugs to <r-bugs@r-project.org>.",
             sep = "\n")
@@ -644,7 +645,7 @@ function(pkgdir, outfile, title, batch = FALSE,
                 R.version[["major"]], ".",  R.version[["minor"]],
                 " (r", R.version[["svn rev"]], ")\n", sep = "")
             cat("",
-                "Copyright (C) 2000-2010 The R Core Development Team.",
+                "Copyright (C) 2000-2011 The R Core Development Team.",
                 "This is free software; see the GNU General Public License version 2",
                 "or later for copying conditions.  There is NO warranty.",
                 sep="\n")
