@@ -278,7 +278,7 @@ getVignetteEncoding <-  function(file, ...)
 .getVignetteEncoding <- function(lines, convert = FALSE)
 {
     ## Look for input enc lines using inputenc or inputenx
-    ## Note, multiple languages are excluded.
+    ## Note, multiple encodings are excluded.
 
     poss <-
         grep("^[[:space:]]*\\\\usepackage\\[([[:alnum:]]+)\\]\\{inputen[cx]\\}",
@@ -301,14 +301,21 @@ getVignetteEncoding <-  function(file, ...)
         ## Currently utf8, utf8x, latin1, latin9 and ansinew are in use.
         switch(res,
                "utf8" =, "utf8x" = "UTF-8",
-               "latin1" = "latin1",
-               "latin2" = "latin2",
-               "latin9" = "LATIN-9", # only form known to GNU libiconv
-               "arabic" = "ISO-8859-6",
-               "cyrillic" = "ISO-8859-5",
-               "greek" = "ISO-8859-7",
-               "hebrew" = "ISO-8859-8",
+               "latin1" =, "iso-8859-1" = "latin1",
+               "latin2" =, "iso-8859-2" = "latin2",
+               "latin9" =, "iso-8859-15" = "latin-9", # only form known to GNU libiconv
+               "latin10" =, "iso-8859-16" = "latin10",
+               "cyrillic" =, "iso-8859-5" =  "ISO-8859-5", # inputenx
+               "koi8-r" =  "KOI8-R", # inputenx
+               "arabic" = "ISO-8859-6", # Not clear next 3 are known to latex
+               "greek" =, "iso-8859-7" = "ISO-8859-7",
+               "hebrew" =, "iso-8859-8" = "ISO-8859-8",
                "ansinew" = "CP1252",
+               "applemac" = "macroman",
+               ## assume these only get used on Windows
+               "cp1250" = "CP1250",
+               "cp1252" = "CP1252",
+               "cp1257" = "CP1257",
                "unknown")
     } else res
 }
@@ -320,7 +327,7 @@ function(lines, tag)
 {
     meta_RE <- paste("[[:space:]]*%+[[:space:]]*\\\\Vignette", tag,
                      "\\{([^}]*)\\}", sep = "")
-    meta <- grep(meta_RE, lines, value = TRUE)
+    meta <- grep(meta_RE, lines, value = TRUE, useBytes = TRUE)
     .strip_whitespace(gsub(meta_RE, "\\1", meta))
 }
 
@@ -330,7 +337,7 @@ function(file)
     lines <- readLines(file, warn = FALSE)
 
     ## <FIXME>
-    ## Can only proceed with lines with are valid in the current locale.
+    ## Can only proceed with lines which are valid in the current locale.
     ## Unfortunately, vignette encodings are a mess: package encodings
     ## might apply, but be overridden by \inputencoding commands.
     ## For now, assume that vignette metadata occur in all ASCII lines.
@@ -512,14 +519,17 @@ function(vigDeps)
 ### helper for R CMD check
 
 .run_one_vignette <-
-    function(vig_name, docDir)
+    function(vig_name, docDir, encoding = "")
 {
+    ## The idea about encodings here is that Stangle reads the
+    ## file, converts on read and outputs in the current encoding.
+    ## Then source() can assume the current encoding.
     td <- tempfile()
     dir.create(td)
     file.copy(docDir, td, recursive = TRUE)
     setwd(file.path(td, "doc"))
     result <- NULL
-    tryCatch(utils::Stangle(vig_name, quiet = TRUE),
+    tryCatch(utils::Stangle(vig_name, quiet = TRUE, encoding = encoding),
              error = function(e) result <<- conditionMessage(e))
     if(length(result)) {
         cat("\n  When tangling ", sQuote(vig_name), ":\n", sep="")
@@ -532,6 +542,7 @@ function(vigDeps)
         cat("\n  When sourcing ", sQuote(f), ":\n", sep="")
         stop(result, call. = FALSE, domain = NA)
     }
+    cat("\n *** Run successfully completed ***\n")
 }
 
 ### Local variables: ***
