@@ -8,11 +8,11 @@ function(given = NULL, family = NULL, middle = NULL,
          email = NULL, role = NULL, comment = NULL,
          first = NULL, last = NULL)
 {
-    ## arrange all arguments in lists of equal length
+    ## Arrange all arguments in lists of equal length.
     args <- list(given = given, family = family, middle = middle,
                  email = email, role = role, comment = comment,
 		 first = first, last = last)
-    args <- lapply(args, function(x) if(inherits(x, "list")) x else list(x))
+    args <- lapply(args, .listify)
     args_length <- sapply(args, length)
     if(!all(args_length_ok <- args_length %in% c(1L, max(args_length))))
         warning(sprintf("Not all arguments are of the same length, the following need to be recycled: %s",
@@ -23,7 +23,7 @@ function(given = NULL, family = NULL, middle = NULL,
     ## We could do this more elegantly, but let's just go through the
     ## list processing person by person.  I'm just recycling the old
     ## person() code for this.
-    ## </COMMENT>    
+    ## </COMMENT>
     person1 <-
     function(given = NULL, family = NULL, middle = NULL,
              email = NULL, role = NULL, comment = NULL,
@@ -52,12 +52,9 @@ function(given = NULL, family = NULL, middle = NULL,
             ## <FIXME>
             ## Start warning eventually ... maybe use message() for now?
             message("It is recommended to use 'family' instead of 'last'.")
-	    ## <COMMENT Z>
-            ## I don't think you mean that!
-            ## </COMMENT>
             ## </FIXME>
             family <- last
-        } 
+        }
 
         ## Set all empty arguments to NULL.
         if(.is_not_nonempty_text(given)) given <- NULL
@@ -76,10 +73,10 @@ function(given = NULL, family = NULL, middle = NULL,
         ##   tools:::.valid_maintainer_field_regexp
         ## to validate given email addresses.
         ## </FIXME>
- 
+
         if(length(role))
             role <- .canonicalize_person_role(role)
- 
+
         rval <- list(given = given, family = family, role = role,
                      email = email, comment = comment)
         ## Canonicalize 0-length character arguments to NULL.
@@ -128,8 +125,8 @@ function(role)
     role
 }
 
-"[[.person" <-
-"[.person" <-
+`[[.person` <-
+`[.person` <-
 function(x, i)
 {
     rval <- unclass(x)[i]
@@ -137,7 +134,7 @@ function(x, i)
     return(rval)
 }
 
-print.person <- 
+print.person <-
 function(x, ...)
 {
     x_char <- sapply(x, format, ...)
@@ -145,7 +142,7 @@ function(x, ...)
     invisible(x)
 }
 
-"$.person" <- 
+`$.person` <-
 function(x, name)
 {
     ## <COMMENT Z>
@@ -160,7 +157,7 @@ function(x, name)
     ## Let's be nice and support first/middle/last for now.
     ## </COMMENT>
     if(name %in% c("first", "last", "middle")) {
-        message("It is recommended to use given/family instead of first/middle/last.")    
+        message("It is recommended to use given/family instead of first/middle/last.")
         oname <- name
 	name <- switch(name,
 	    "first" = "given",
@@ -170,9 +167,9 @@ function(x, name)
     } else {
         oname <- name
     }
-    
+
     rval <- lapply(unclass(x), function(p) p[[name]])
-    
+
     if(oname == "first") rval <- lapply(rval, head, 1L)
     if(oname == "middle") {
         rval <- lapply(rval, tail, -1L)
@@ -184,12 +181,11 @@ function(x, name)
     rval
 }
 
-"$<-.person" <- 
+`$<-.person` <-
 function(x, name, value)
 {
     name <- match.arg(name, c("given", "family", "role", "email", "comment"))
-    x <- unclass(x)
-    if(!inherits(value, "list")) value <- list(value)
+    x <- .listify(unclass(x))
     value <- rep(value, length.out = length(x))
 
     if(name == "role")
@@ -202,7 +198,7 @@ function(x, name, value)
     x
 }
 
-c.person <- 
+c.person <-
 function(..., recursive = FALSE)
 {
     args <- list(...)
@@ -222,7 +218,7 @@ as.person.default <-
 function(x)
 {
     if(inherits(x, "person")) return(x)
-    
+
     x <- as.character(x)
     x <- do.call("c",
                  strsplit(x, "[[:space:]]?(,|[[:space:]]and)[[:space:]]+"))
@@ -281,7 +277,7 @@ function(x,
          include = c("given", "family", "email", "role", "comment"),
          braces =
          list(given = "", family = "", email = c("<", ">"),
-              role = c("[", "]"), comment = c("(", ")")), 
+              role = c("[", "]"), comment = c("(", ")")),
          collapse =
          list(given = " ", family = " ", email = ", ",
               role = ", ", comment = ", "),
@@ -290,7 +286,7 @@ function(x,
 {
     args <- c("given", "family", "email", "role", "comment")
     include <- sapply(include, match.arg, args)
-    
+
     ## process defaults
     braces <- braces[args]
     collapse <- collapse[args]
@@ -307,7 +303,7 @@ function(x,
     if(is.null(collapse$role)) collapse$role <- ", "
     if(is.null(collapse$comment)) collapse$comment <- ", "
     collapse <- lapply(collapse, rep, length.out = 1L)
-    
+
     ## extract selected elements
     x <- lapply(unclass(x), "[", include)
     braces <- braces[include]
@@ -321,8 +317,8 @@ function(x,
         rval <- paste(do.call("c", rval), collapse = " ")
 	rval
     }
-    
-    sapply(x, format_person1)  
+
+    sapply(x, format_person1)
 }
 
 as.character.person <-
@@ -349,13 +345,13 @@ function(bibtype, textVersion=NULL, header = NULL, footer = NULL, key = NULL,
         stop("at least one field has to be specified")
     if(any(sapply(names(args), .is_not_nonempty_text))) stop("all fields have to be named")
 
-    ## arrange all arguments in lists of equal length    
+    ## arrange all arguments in lists of equal length
     args <- c(list(bibtype = bibtype, textVersion = textVersion,
               header = header, footer = footer, key = key), list(...))
-    args <- lapply(args, function(x) if(inherits(x, "list")) x else list(x))
-    other <- lapply(other, function(x) if(inherits(x, "list")) x else list(x))
+    args <- lapply(args, .listify)
+    other <- lapply(other, .listify)
     max_length <- max(sapply(c(args, other), length))
-    
+
     args_length <- sapply(args, length)
     if(!all(args_length_ok <- args_length %in% c(1L, max_length)))
         warning(sprintf("Not all arguments are of the same length, the following need to be recycled: %s",
@@ -429,8 +425,8 @@ function(bibtype, textVersion=NULL, header = NULL, footer = NULL, key = NULL,
     rval
 }
 
-"[[.bibentry" <-
-"[.bibentry" <-
+`[[.bibentry` <-
+`[.bibentry` <-
 function(x, i)
 {
     rval <- unclass(x)[i]
@@ -438,12 +434,20 @@ function(x, i)
     rval
 }
 
+bibentry_format_styles <-
+    c("text", "Bibtex", "citation", "html", "latex", "textVersion")
+
 format.bibentry <-
-function(x,
-         style = c("text", "html", "latex", "Bibtex", "textVersion"), 
-         .bibstyle = "JSS", ...)
+function(x, style = "text", .bibstyle = "JSS", ...)
 {
-    style <- match.arg(style)
+    ind <- pmatch(tolower(style), tolower(bibentry_format_styles),
+                  nomatch = 0L)
+    if(all(ind == 0L))
+        stop(gettextf("'style' should be one of %s",
+                      paste(dQuote(bibentry_format_styles),
+                            collapse = ", ")),
+             domain = NA)
+    style <- bibentry_format_styles[ind]
 
     .format_bibentry_via_Rd <- function(f) {
         out <- file()
@@ -458,6 +462,31 @@ function(x,
                })
     }
 
+    .format_bibentry_as_citation <- function(x) {
+        bibtex <- length(x) < 2L
+
+        c(paste(strwrap(attr(x, "mheader")), collapse = "\n"),
+          unlist(lapply(x, function(y) {
+              paste(c(if(!is.null(y$header))
+                      c(strwrap(y$header), ""),
+                      if(!is.null(y$textVersion)) {
+                          strwrap(y$textVersion, prefix = "  ")
+                      } else {
+                          format(y)
+                      },
+                      if(bibtex) {
+                          c("\nA BibTeX entry for LaTeX users is\n",
+                            paste("  ", unclass(toBibtex(y)),
+                                  sep = ""))
+                      },
+                      if(!is.null(y$footer))
+                      c("", strwrap(y$footer))),
+                    collapse = "\n")
+          })),
+          paste(strwrap(attr(x, "mfooter")), collapse = "\n")
+          )
+    }
+
     switch(style,
            "text" = .format_bibentry_via_Rd(tools::Rd2txt),
            "html" = .format_bibentry_via_Rd(tools::Rd2HTML),
@@ -471,59 +500,37 @@ function(x,
                out <- lapply(unclass(x), attr, "textVersion")
                out[!sapply(out, length)] <- ""
                unlist(out)
-           }
+           },
+           "citation" = .format_bibentry_as_citation(x)
            )
 }
 
 print.bibentry <-
-function(x,
-         style = c("text", "Bibtex", "citation", "html", "latex",
-                   "textVersion"), 
-         .bibstyle = "JSS", ...)
+function(x, style = "text", .bibstyle = "JSS", ...)
 {
-    style <- match.arg(style)
+    y <- format(x, style)
+    n <- length(y)
 
-    ## Printing in citation style does extra headers/footers and more,
-    ## so is handled directly.
+    if(n > length(x)) {
+        ## Printing in citation style does extra headers/footers (which
+        ## however we may empty), so it is handled differently.
+        if(nzchar(header <- y[1L]))
+            header <- c("", header, "")
+        if(nzchar(footer <- y[n]))
+            footer <- c("", footer, "")
+        writeLines(c(header,
+                     paste(y[-c(1L, n)], collapse = "\n\n"),
+                     footer))
+    } else
+        writeLines(paste(y, collapse = "\n\n"))
 
-    .format_bibentry_as_citation <- function(x) {
-        bibtex <- length(x) < 2L
-        c("",
-          if(!is.null(attr(x, "mheader")))
-          c(strwrap(attr(x, "mheader")), ""),
-          do.call(paste,
-                  c(lapply(x, function(y) {
-                      paste(c(if(!is.null(y$header))
-                              c(strwrap(y$header), ""),
-                              if(!is.null(y$textVersion)) {
-                                  strwrap(y$textVersion, prefix = "  ")
-                              } else {
-                                  format(y)
-                              },
-                              if(bibtex) {
-                                  c("\nA BibTeX entry for LaTeX users is\n",
-                                    paste("  ", unclass(toBibtex(y)),
-                                          sep = ""))
-                              },
-                              if(!is.null(y$footer))
-                              c("", strwrap(y$footer))),
-                            collapse = "\n")
-                  }),
-                    list(sep = "\n\n"))),
-          if(!is.null(attr(x, "mfooter")))
-          c("", strwrap(attr(x, "mfooter"))),
-          "")
-    }
-
-    if(style == "citation")
-        writeLines(.format_bibentry_as_citation(x))
-    else
-        writeLines(paste(format(x, style), collapse = "\n\n"))
-
-    invisible(x)    
+    invisible(x)
 }
 
-"$.bibentry" <- 
+bibentry_attribute_names <-
+    c("bibtype", "textVersion", "header", "footer", "key")
+
+`$.bibentry` <-
 function(x, name)
 {
     ## <COMMENT Z>
@@ -531,36 +538,34 @@ function(x, name)
     ## otherwise (to mirror the behaviour of the input format for
     ## bibentry())
     ## </COMMENT>
-    is_attribute <-
-        name %in% c("bibtype", "textVersion", "header", "footer", "key")
+    is_attribute <- name %in% bibentry_attribute_names
     rval <- if(is_attribute) lapply(unclass(x), attr, name)
         else lapply(unclass(x), "[[", name)
     if(length(rval) == 1L) rval <- rval[[1L]]
     rval
 }
 
-"$<-.bibentry" <- 
+`$<-.bibentry` <-
 function(x, name, value)
 {
-    is_attribute <-
-        name %in% c("bibtype", "textVersion", "header", "footer", "key")
+    is_attribute <- name %in% bibentry_attribute_names
+
     x <- unclass(x)
     name <- tolower(name)
-    
+
     ## recycle value
-    if(!inherits(value, "list")) value <- list(value)
-    value <- rep(value, length.out = length(x))
+    value <- rep(.listify(value), length.out = length(x))
 
     ## check bibtype
     if(name == "bibtype") {
       stopifnot(all(sapply(value, length) == 1L))
       BibTeX_names <- names(tools:::BibTeX_entry_field_db)
-      value <- unlist(value)      
+      value <- unlist(value)
       pos <- match(tolower(value), tolower(BibTeX_names))
       if(any(is.na(pos)))
           stop("'bibtype' has to be one of",
                paste(BibTeX_names, collapse = ", "))
-      value <- as.list(BibTeX_names[pos])    
+      value <- as.list(BibTeX_names[pos])
     }
 
     ## replace all values
@@ -590,13 +595,13 @@ function(x, name, value)
 		paste(rfields[!ok], collapse = ", "), sep = "")
         }
     }
-    for(i in seq_along(x)) check_bibentry1(x[[i]])    
-    
+    for(i in seq_along(x)) check_bibentry1(x[[i]])
+
     class(x) <- "bibentry"
     x
 }
 
-c.bibentry <- 
+c.bibentry <-
 function(..., recursive = FALSE)
 {
     args <- list(...)
@@ -611,7 +616,7 @@ function(..., recursive = FALSE)
 toBibtex.bibentry <-
 function(object, ...)
 {
-    format_author <- function(author) paste(sapply(author, function(p) {        
+    format_author <- function(author) paste(sapply(author, function(p) {
 	fnms <- p$family
 	only_given_or_family <- is.null(fnms) || is.null(p$given)
 	fbrc <- if(length(fnms) > 1L ||
@@ -633,7 +638,7 @@ function(object, ...)
     	"}", "")
         return(rval)
     }
-    
+
     rval <- head(unlist(lapply(object, format_bibentry1)), -1L)
     class(rval) <- "Bibtex"
     rval
@@ -671,7 +676,7 @@ function(file, meta = NULL)
     mheader <- NULL
     mfooter <- NULL
     k <- 0L
-    envir <- new.env()
+    envir <- new.env(hash = TRUE)
     ## Make the package metadata available to the citation entries.
     assign("meta", meta, envir = envir)
 
@@ -693,7 +698,7 @@ function(file, meta = NULL)
         attr(rval, "mheader") <- paste(mheader, collapse = "\n")
     if(!.is_not_nonempty_text(mfooter))
         attr(rval, "mfooter") <- paste(mfooter, collapse = "\n")
-    
+
     .citation(rval)
 }
 
@@ -710,7 +715,7 @@ function(package = "base", lib.loc = NULL, auto = NULL)
 
     ## if(is.null(auto)): Use default auto-citation if no CITATION
     ## available.
-    citfile <- file.path(dir, "CITATION")    
+    citfile <- file.path(dir, "CITATION")
     if(is.null(auto)) auto <- !file_test("-f", citfile)
 
     ## if CITATION is available
@@ -727,7 +732,7 @@ function(package = "base", lib.loc = NULL, auto = NULL)
     if((!is.null(meta$Priority)) && (meta$Priority == "base")) {
     	cit <- citation("base", auto = FALSE)
     	attr(cit, "mheader")[1L] <-
-            paste("The '", package, "' package is part of R.  ",
+            paste("The ", sQuote(package), " package is part of R.  ",
                   attr(cit, "mheader")[1L], sep = "")
         return(.citation(cit))
     }
@@ -755,7 +760,7 @@ function(package = "base", lib.loc = NULL, auto = NULL)
     } else {
         author <- as.personList(meta$Author)
     }
-                
+
     z <- list(title = paste(package, ": ", meta$Title, sep=""),
               author = author,
               year = year,
@@ -775,7 +780,7 @@ function(package = "base", lib.loc = NULL, auto = NULL)
         if(!is.null(rfr <- meta$"Repository/R-Forge/Revision"))
             z$note <- paste(z$note, rfr, sep = "/r")
     }
-    
+
     footer <- if(!("recommended" %in% meta$Priority) && !has_enhanced_author_spec)
             paste("ATTENTION: This citation information has been auto-generated",
                   "from the package DESCRIPTION file and may need manual editing,",
@@ -808,7 +813,7 @@ function(package = "base", lib.loc = NULL, auto = NULL)
 function(x)
 {
     out <- eval(parse(text = x))
-    
+
     ## Let's by nice ...
     ## Alternatively, we could throw an error.
     if(!inherits(out, "person"))
@@ -816,7 +821,7 @@ function(x)
     ## Barf if we got no authors at all.
     if(!any(sapply(out, .person_has_author_role)))
         stop("Enhanced author specification provides no authors.")
-    
+
     out
 }
 
@@ -827,8 +832,25 @@ function(x)
 }
 
 print.citation <-
-function(x, ...)
+function(x, style = "citation", ...)
 {
-    NextMethod("print", x, style = "citation")
+    NextMethod("print", x, style = style, ...)
     invisible(x)
 }
+
+as.bibentry <-
+function(x)
+    UseMethod("as.bibentry")
+
+as.bibentry.bibentry <- identity
+
+as.bibentry.citation <-
+function(x)
+{
+    class(x) <- "bibentry"
+    x
+}
+
+.listify <-
+function(x)
+    if(inherits(x, "list")) x else list(x)
