@@ -47,13 +47,13 @@ function(file, header = FALSE, sep = "", quote = "\"'", dec = ".",
 {
     if(is.character(file)) {
         file <- if(nzchar(fileEncoding))
-            file(file, "r", encoding = fileEncoding) else file(file, "r")
+            file(file, "rt", encoding = fileEncoding) else file(file, "rt")
         on.exit(close(file))
     }
     if(!inherits(file, "connection"))
         stop("'file' must be a character string or connection")
-    if(!isOpen(file, "r")) {
-        open(file, "r")
+    if(!isOpen(file, "rt")) {
+        open(file, "rt")
         on.exit(close(file))
     }
 
@@ -102,7 +102,9 @@ function(file, header = FALSE, sep = "", quote = "\"'", dec = ".",
         if(!header) rlabp <- FALSE
 
         if (header) {
-            readLines(file, 1L)          # skip over header
+            ## skip over header
+           .Internal(readTableHead(file, 1L, comment.char,
+                                   blank.lines.skip, quote, sep))
             if(missing(col.names)) col.names <- first
             else if(length(first) != length(col.names))
                 warning("header and 'col.names' are of different lengths")
@@ -143,8 +145,8 @@ function(file, header = FALSE, sep = "", quote = "\"'", dec = ".",
     names(what) <- col.names
 
     colClasses[colClasses %in% c("real", "double")] <- "numeric"
-    known <- colClasses %in%
-                c("logical", "integer", "numeric", "complex", "character")
+    known <- colClasses %in% c("logical", "integer", "numeric", "complex",
+                               "character", "raw")
     what[known] <- sapply(colClasses[known], do.call, list(0))
     what[colClasses %in% "NULL"] <- list(NULL)
     keep <- !sapply(what, is.null)
@@ -238,7 +240,7 @@ function(file, header = FALSE, sep = "", quote = "\"'", dec = ".",
     if(!compactRN) {
         if (length(row.names) != nlines)
             stop("invalid 'row.names' length")
-        if (any(duplicated(row.names)))
+        if (anyDuplicated(row.names))
             stop("duplicate 'row.names' are not allowed")
         if (any(is.na(row.names)))
             stop("missing values in 'row.names' are not allowed")
