@@ -17,9 +17,11 @@
 vignette <-
     function(topic, package = NULL, lib.loc = NULL, all = TRUE)
 {
-    if(is.null(package))
+    if (is.null(package)) {
         package <- .packages(all.available = all, lib.loc)
-    paths <- .find.package(package, lib.loc)
+        ## allow for misnamed dirs
+        paths <- find.package(package, lib.loc, quiet = TRUE)
+    } else paths <- find.package(package, lib.loc)
 
     ## Find the directories with a 'doc' subdirectory *possibly*
     ## containing vignettes.
@@ -79,7 +81,7 @@ vignette <-
             ## Check for new-style 'Meta/vignette.rds' ...
             if(file.exists(INDEX <-
                            file.path(dir, "Meta", "vignette.rds")))
-                entries <- .readRDS(INDEX)
+                entries <- readRDS(INDEX)
             if(NROW(entries) > 0)
                 vDB <- rbind(vDB,
                              cbind(dir,
@@ -123,11 +125,12 @@ print.vignette <- function(x, ...){
         ## <FIXME>
         ## Should really abstract this into a BioC style
         ## openPDF() along the lines of browseURL() ...
-        if(.Platform$OS.type == "windows")
+        pdfviewer <- getOption("pdfviewer")
+        if(identical(pdfviewer, "false")) {
+        } else if(.Platform$OS.type == "windows" &&
+                  identical(pdfviewer, file.path(R.home("bin"), "open.exe")))
             shell.exec(x$pdf)
-        else
-            system(paste(shQuote(getOption("pdfviewer")), shQuote(x$pdf)),
-                   wait = FALSE)
+        else system2(pdfviewer, shQuote(x$pdf), wait = FALSE)
         ## </FIXME>
     } else {
         warning(gettextf("vignette '%s' has no PDF", x$topic),
@@ -139,7 +142,7 @@ print.vignette <- function(x, ...){
 edit.vignette <- function(name, ...)
 {
 
-    f <- paste(tempfile(name$topic), ".R", sep="")
+    f <- tempfile(name$topic, fileext=".R")
     Stangle(name$file, output=f, quiet=TRUE)
     file.edit(file=f, ...)
 }
