@@ -166,10 +166,10 @@ R_common_command_line(int *pac, char **argv, Rstart Rp)
 	    }
 	    else if (!strncmp(*av, "--encoding", 10)) {
 		if(strlen(*av) < 12) {
-		    ac--; av++; p = *av;
+		    if(ac > 1) {ac--; av++; p = *av;} else p = NULL;
 		} else p = &(*av)[11];
 		if (p == NULL) {
-		    R_ShowMessage(_("WARNING: no value given for --encoding given\n"));
+		    R_ShowMessage(_("WARNING: no value given for --encoding"));
 		} else {
 		    strncpy(R_StdinEnc, p, 30);
 		    R_StdinEnc[30] = '\0';
@@ -192,7 +192,7 @@ R_common_command_line(int *pac, char **argv, Rstart Rp)
 		     !strcmp(*av, "-n") ||
 		     !strcmp(*av, "-v")) {
 		snprintf(msg, 1024,
-			 _("WARNING: option '%s' no longer supported\n"), *av);
+			 _("WARNING: option '%s' no longer supported"), *av);
 		R_ShowMessage(msg);
 	    }
 	    /* mop up --max/min/-n/vsize */
@@ -201,12 +201,12 @@ R_common_command_line(int *pac, char **argv, Rstart Rp)
 		     !strncmp(*av, "--min-vsize", 11) ||
 		     !strncmp(*av, "--max-vsize", 11) ) {
 		if(strlen(*av) < 13) {
-		    ac--; av++; p = *av;
+		    if(ac > 1) {ac--; av++; p = *av;} else p = NULL;
 		}
 		else p = &(*av)[12];
 		if (p == NULL) {
 		    snprintf(msg, 1024,
-			     _("WARNING: no value given for '%s'\n"), *av);
+			     _("WARNING: no value given for '%s'"), *av);
 		    R_ShowMessage(msg);
 		    break;
 		}
@@ -214,11 +214,11 @@ R_common_command_line(int *pac, char **argv, Rstart Rp)
 		if(ierr) {
 		    if(ierr < 0)
 			snprintf(msg, 1024,
-				 _("WARNING: '%s' value is invalid: ignored\n"),
+				 _("WARNING: '%s' value is invalid: ignored"),
 				 *av);
 		    else
 			sprintf(msg,
-				_("WARNING: %s: too large and ignored\n"),
+				_("WARNING: %s: too large and ignored"),
 				*av);
 		    R_ShowMessage(msg);
 
@@ -231,20 +231,20 @@ R_common_command_line(int *pac, char **argv, Rstart Rp)
 	    }
 	    else if(strncmp(*av, "--max-ppsize", 12) == 0) {
 		if(strlen(*av) < 14) {
-		    ac--; av++; p = *av;
+		    if(ac > 1) {ac--; av++; p = *av;} else p = NULL;
 		} else p = &(*av)[13];
 		if (p == NULL) {
-		    R_ShowMessage(_("WARNING: no value given for '--max-ppsize'\n"));
+		    R_ShowMessage(_("WARNING: no value given for '--max-ppsize'"));
 		    break;
 		}
 		lval = strtol(p, &p, 10);
 		if (lval < 0)
-		    R_ShowMessage(_("WARNING: '--max-ppsize' value is negative: ignored\n"));
+		    R_ShowMessage(_("WARNING: '--max-ppsize' value is negative: ignored"));
 		else if (lval < 10000)
-		    R_ShowMessage(_("WARNING: '--max-ppsize' value is too small: ignored\n"));
+		    R_ShowMessage(_("WARNING: '--max-ppsize' value is too small: ignored"));
 
 		else if (lval > 500000)
-		    R_ShowMessage(_("WARNING: '--max-ppsize' value is too large: ignored\n"));
+		    R_ShowMessage(_("WARNING: '--max-ppsize' value is too large: ignored"));
 		else Rp->ppsize = lval;
 	    }
 	    else { /* unknown -option */
