@@ -1,7 +1,6 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
- *  Copyright (C) 1995-2006	Robert Gentleman, Ross Ihaka and the
- *				R Development Core Team
+ *  Copyright (C) 1995-2011	The R Development Core Team
  *  Copyright (C) 2003		The R Foundation
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -669,6 +668,8 @@ SEXP attribute_hidden do_cov(SEXP call, SEXP op, SEXP args, SEXP env)
 	na_fail = TRUE;
 	break;
     case 2:		/* complete */
+	/* did na.omit in R */
+	if (!LENGTH(x)) error(_("no complete element pairs"));
 	break;
     case 3:		/* pairwise.complete */
 	pair = TRUE;
@@ -765,12 +766,12 @@ SEXP attribute_hidden do_cov(SEXP call, SEXP op, SEXP args, SEXP env)
 	else {
 	    x = getAttrib(x, R_DimNamesSymbol);
 	    y = getAttrib(y, R_DimNamesSymbol);
-	    if ((!isNull(x) && !isNull(VECTOR_ELT(x, 1))) ||
-		(!isNull(y) && !isNull(VECTOR_ELT(y, 1)))) {
+	    if ((length(x) >= 2 && !isNull(VECTOR_ELT(x, 1))) ||
+		(length(y) >= 2 && !isNull(VECTOR_ELT(y, 1)))) {
 		PROTECT(ind = allocVector(VECSXP, 2));
-		if (!isNull(x) && !isNull(VECTOR_ELT(x, 1)))
+		if (length(x) >= 2 && !isNull(VECTOR_ELT(x, 1)))
 		    SET_VECTOR_ELT(ind, 0, duplicate(VECTOR_ELT(x, 1)));
-		if (!isNull(y) && !isNull(VECTOR_ELT(y, 1)))
+		if (length(y) >= 2 && !isNull(VECTOR_ELT(y, 1)))
 		    SET_VECTOR_ELT(ind, 1, duplicate(VECTOR_ELT(y, 1)));
 		setAttrib(ans, R_DimNamesSymbol, ind);
 		UNPROTECT(1);
