@@ -124,9 +124,11 @@ SEXP attribute_hidden do_readDCF(SEXP call, SEXP op, SEXP args, SEXP env)
 			need += strlen(line+regmatch[0].rm_eo);
 		    }
 		    if(buflen < need) {
-			buf = (char *) realloc(buf, need);
-			if(!buf)
+			char *tmp = (char *) realloc(buf, need);
+			if(!tmp) {
+			    free(buf);
 			    error(_("could not allocate memory for 'read.dcf'"));
+			} else buf = tmp;
 			buflen = need;
 		    }
 		    strcpy(buf,CHAR(STRING_ELT(retval, lastm + nwhat*k)));
@@ -177,9 +179,11 @@ SEXP attribute_hidden do_readDCF(SEXP call, SEXP op, SEXP args, SEXP env)
 			what = what2;
 			need = strlen(line+regmatch[0].rm_eo);
 			if(buflen < need){
-			    buf = (char *) realloc(buf, need);
-			    if(!buf)
+			    char *tmp = (char *) realloc(buf, need);
+			    if(!tmp) {
+				free(buf);
 				error(_("could not allocate memory for 'read.dcf'"));
+			    } else buf = tmp;
 			    buflen = need;
 			}
 			strncpy(buf, line, Rf_strchr(line, ':') - line);
