@@ -1,7 +1,7 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
  *  Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
- *  Copyright (C) 1997--2010  The R Development Core Team
+ *  Copyright (C) 1997--2011  The R Development Core Team
  *  Copyright (C) 2002--2005  The R Foundation
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -3013,11 +3013,7 @@ void GArrow(double xfrom, double yfrom, double xto, double yto, int coords,
     if((code & 3) == 0) return; /* no arrows specified */
     if(length == 0) return; /* zero-length arrow heads */
 
-#ifdef HAVE_HYPOT
     if(hypot(xfromInch - xtoInch, yfromInch - ytoInch) < eps) {
-#else
-    if(pythag(xfromInch - xtoInch, yfromInch - ytoInch) < eps) {
-#endif
 	/* effectively 0-length arrow */
 	warning(_("zero-length arrow is of indeterminate angle and so skipped"));
 	return;
@@ -3217,7 +3213,7 @@ void GMtext(const char *str, cetype_t enc, int side, double line, int outer,
 	 3 = always vertical.
 */
     double angle, xadj;
-    int coords, subcoords;
+    int coords;
 
     /* Init to keep -Wall happy: */
     angle = 0.;
@@ -3231,7 +3227,6 @@ void GMtext(const char *str, cetype_t enc, int side, double line, int outer,
 	case 3:	    coords = OMA3;	break;
 	case 4:	    coords = OMA4;	break;
 	}
-	subcoords = NIC;
     }
     else {
 	switch(side) {
@@ -3240,7 +3235,6 @@ void GMtext(const char *str, cetype_t enc, int side, double line, int outer,
 	case 3:	    coords = MAR3;	break;
 	case 4:	    coords = MAR4;	break;
 	}
-	subcoords = USER;
     }
     /* Note: I changed gpptr(dd)->yLineBias to 0.3 here. */
     /* Purely visual tuning. RI */
@@ -3249,13 +3243,21 @@ void GMtext(const char *str, cetype_t enc, int side, double line, int outer,
        a somehow fuzzy manner with respect to current side and las settings.
        Uwe L.
     */
+    /* Note from PR#14532:
+       yLineBias is the proportion of line height that is white
+       space. The manipulation of "line" below is pure visual tuning
+       such that when we plot horizontal text on side 1 (or vertical
+       text on side 4) with padj=0 (i.e. text written *above* the
+       specified y-value), it is symmetric w.r.t text written on sides
+       1 and 2 with padj=0.
+    */
     switch(side) {
     case 1:
 	if(las == 2 || las == 3) {
 	    angle = 90;
 	}
 	else {
-	    line = line + 1 - dd->dev->yLineBias;
+	    line += (1/gpptr(dd)->mex)*(1 - dd->dev->yLineBias);
 	    angle = 0;
 	}
 	break;
@@ -3264,7 +3266,7 @@ void GMtext(const char *str, cetype_t enc, int side, double line, int outer,
 	    angle = 0;
 	}
 	else {
-	    line = line + dd->dev->yLineBias;
+	    line += (1/gpptr(dd)->mex)*dd->dev->yLineBias;
 	    angle = 90;
 	}
 	break;
@@ -3273,7 +3275,7 @@ void GMtext(const char *str, cetype_t enc, int side, double line, int outer,
 	    angle = 90;
 	}
 	else {
-	    line = line + dd->dev->yLineBias;
+	    line += (1/gpptr(dd)->mex)*dd->dev->yLineBias;
 	    angle = 0;
 	}
 	break;
@@ -3282,7 +3284,7 @@ void GMtext(const char *str, cetype_t enc, int side, double line, int outer,
 	    angle = 0;
 	}
 	else {
-	    line = line + 1 - dd->dev->yLineBias;
+	    line += (1/gpptr(dd)->mex)*(1 - dd->dev->yLineBias);
 	    angle = 90;
 	}
 	break;
@@ -3347,7 +3349,7 @@ void GMathText(double x, double y, int coords, SEXP expr,
 void GMMathText(SEXP str, int side, double line, int outer,
 		double at, int las, double yadj, pGEDevDesc dd)
 {
-    int coords = 0, subcoords;
+    int coords = 0;
     double xadj, angle = 0;
 
     /* IF font metric information is not available for device */
@@ -3372,7 +3374,6 @@ void GMMathText(SEXP str, int side, double line, int outer,
 	case 3:	    coords = OMA3;	break;
 	case 4:	    coords = OMA4;	break;
 	}
-	subcoords = NIC;
     }
     else {
 	switch(side) {
@@ -3381,7 +3382,6 @@ void GMMathText(SEXP str, int side, double line, int outer,
 	case 3:	    coords = MAR3;	break;
 	case 4:	    coords = MAR4;	break;
 	}
-	subcoords = USER;
     }
     switch(side) {
     case 1:
@@ -3392,7 +3392,8 @@ void GMMathText(SEXP str, int side, double line, int outer,
 	    /*	    line = line + 1 - gpptr(dd)->yLineBias;
 		    angle = 0;
 		    yadj = NA_REAL; */
-	    line = line + 1;
+	    // line += (1/gpptr(dd)->mex)*(1 - dd->dev->yLineBias);
+	    line += 1/gpptr(dd)->mex;
 	    angle = 0;
 	}
 	break;
@@ -3404,6 +3405,9 @@ void GMMathText(SEXP str, int side, double line, int outer,
 	    /*	    line = line + gpptr(dd)->yLineBias;
 		    angle = 90;
 		    yadj = NA_REAL; */
+	    /* The following line is needed for symmetry with plain text
+	       but changes existing output */
+	    // line += (1/gpptr(dd)->mex)*dd->dev->yLineBias;
 	    angle = 90;
 	}
 	break;
@@ -3415,6 +3419,9 @@ void GMMathText(SEXP str, int side, double line, int outer,
 	    /*   line = line + gpptr(dd)->yLineBias;
 		 angle = 0;
 		 yadj = NA_REAL; */
+	    /* The following line is needed for symmetry with plain text
+	       but changes existing output */
+	    // line += (1/gpptr(dd)->mex)*dd->dev->yLineBias;
 	    angle = 0;
 	}
 	break;
@@ -3426,7 +3433,8 @@ void GMMathText(SEXP str, int side, double line, int outer,
 	    /*   line = line + 1 - gpptr(dd)->yLineBias;
 		 angle = 90;
 		 yadj = NA_REAL; */
-	    line = line + 1;
+	    // line += (1/gpptr(dd)->mex)*(1 - dd->dev->yLineBias);
+	    line += 1/gpptr(dd)->mex;
 	    angle = 90;
 	}
 	break;
