@@ -38,26 +38,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-#ifndef SUPPORT_MBCS
-void Ri18n_wcswidth(void)
-{
-   return;
-}
-void Ri18n_wcwidth(void)
-{
-   return;
-}
-void Ri18n_wctype(void)
-{
-   return;
-}
-void Ri18n_iswctype(void)
-{
-   return;
-}
-
-#else /* SUPPORT_MBCS */
-
 #define IN_RLOCALE_C 1 /* used in rlocale.h */
 #include <R_ext/rlocale.h>
 #include "rlocale_data.h"
@@ -192,8 +172,8 @@ static int wcsearch(int wint, const struct interval *table, int max)
  *  (wchar_t != unicode)
  *  However, it is Unicode at the time of UTF-8.
  ********************************************************************/
-#if defined(HAVE_ICONV) && defined(ICONV_LATIN1) && defined(__APPLE_CC__)
-/* allow for MacIntel platforms */
+#if defined(__APPLE_CC__)
+/* allow for both PPC and Intel platforms */
 #ifdef WORDS_BIGENDIAN
 static const char UNICODE[] = "UCS-4BE";
 #else
@@ -331,5 +311,3 @@ int Ri18n_iswctype(wint_t wc, wctype_t desc)
 	     Ri18n_wctype_func[i].wctype != desc ; i++ );
     return (*Ri18n_wctype_func[i].func)(wc);
 }
-
-#endif /* SUPPORT_MBCS */
