@@ -13,8 +13,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  along with this program; if not, a copy is available at
+ *  http://www.r-project.org/Licenses/
  *
  *  SYNOPSIS
  *
@@ -32,3 +32,9 @@ int imax2(int x, int y)
 {
     return (x < y) ? y : x;
 }
+
+/* force to be pulled in */
+double pythag(double a, double b)
+{
+    return hypot(a, b);
+}
