@@ -3,16 +3,16 @@
  *  original  (C) 1992	     Royal Statistical Society
  *
  *  Computes the noncentral chi-squared distribution function with
- *  positive real degrees of freedom f and nonnegative noncentrality
- *  parameter theta.  pnchisq_raw is based on
+ *  positive real degrees of freedom df and nonnegative noncentrality
+ *  parameter ncp.  pnchisq_raw is based on
  *
  *    Ding, C. G. (1992)
  *    Algorithm AS275: Computing the non-central chi-squared
  *    distribution function. Appl.Statist., 41, 478-482.
 
  *  Other parts
- *  Copyright (C) 2000-2007  The R Development Core Team
- *  Copyright (C) 2003-2006  The R Foundation
+ *  Copyright (C) 2000-2009  The R Development Core Team
+ *  Copyright (C) 2003-2009  The R Foundation
  */
 
 #include "nmath.h"
@@ -26,25 +26,34 @@
  * bad precision & non-convergence in some cases (x ~= f, both LARGE)
  */
 
-double pnchisq(double x, double f, double theta, int lower_tail, int log_p)
+
+double pnchisq(double x, double df, double ncp, int lower_tail, int log_p)
 {
     double ans;
 #ifdef IEEE_754
-    if (ISNAN(x) || ISNAN(f) || ISNAN(theta))
-	return x + f + theta;
-    if (!R_FINITE(f) || !R_FINITE(theta))
+    if (ISNAN(x) || ISNAN(df) || ISNAN(ncp))
+	return x + df + ncp;
+    if (!R_FINITE(df) || !R_FINITE(ncp))
 	ML_ERR_return_NAN;
 #endif
 
-    if (f < 0. || theta < 0.) ML_ERR_return_NAN;
+    if (df < 0. || ncp < 0.) ML_ERR_return_NAN;
 
-    ans = pnchisq_raw(x, f, theta, 1e-12, 8*DBL_EPSILON, 1000000, lower_tail);
-    if(lower_tail || theta < 80) return log_p ? log(ans) : ans;
-    else {
-	if(ans < 1e-10) ML_ERROR(ME_PRECISION, "pnchisq");
-	ans = fmax2(ans, 0.0);  /* Precaution PR#7099 */
-	return log_p ? log(ans) : ans;
+    ans = pnchisq_raw(x, df, ncp, 1e-12, 8*DBL_EPSILON, 1000000, lower_tail);
+    if(ncp >= 80) {
+	if(lower_tail) {
+	    ans = fmin2(ans, 1.0);  /* e.g., pchisq(555, 1.01, ncp = 80) */
+	} else { /* !lower_tail */
+	    /* since we computed the other tail cancellation is likely */
+	    if(ans < 1e-10) ML_ERROR(ME_PRECISION, "pnchisq");
+	    ans = fmax2(ans, 0.0);  /* Precaution PR#7099 */
+	}
     }
+    if (!log_p) return ans;
+    /* if ans is near one, we can do better using the other tail */
+    if (ncp >= 80 || ans < 1 - 1e-8) return log(ans);
+    ans = pnchisq_raw(x, df, ncp, 1e-12, 8*DBL_EPSILON, 1000000, !lower_tail);
+    return log1p(-ans);
 }
 
 double attribute_hidden
@@ -60,7 +69,12 @@ pnchisq_raw(double x, double f, double theta,
     static const double _dbl_min_exp = M_LN2 * DBL_MIN_EXP;
     /*= -708.3964 for IEEE double precision */
 
-    if (x <= 0.)	return lower_tail ? 0. : 1.;
+    if (x <= 0.) {
+	if(x == 0. && f == 0.)
+	    return lower_tail ? exp(-0.5*theta) : -expm1(-0.5*theta);
+	/* x < 0  or {x==0, f > 0} */
+	return lower_tail ? 0. : 1.;
+    }
     if(!R_FINITE(x))	return lower_tail ? 1. : 0.;
 
     /* This is principally for use from qnchisq */
@@ -68,12 +82,18 @@ pnchisq_raw(double x, double f, double theta,
     R_CheckUserInterrupt();
 #endif
 
-    if(theta < 80) {
-	LDOUBLE sum = 0, lambda = 0.5*theta, pr = exp(-lambda);
+    if(theta < 80) { /* use 110 for Inf, as ppois(110, 80/2, lower.tail=FALSE) is 2e-20 */
+	LDOUBLE sum = 0, sum2 = 0, lambda = 0.5*theta, pr = exp(-lambda);
+	double ans;
 	int i;
-	for(i = 0; i < 100;  pr *= lambda/++i)
+	/* we need to renormalize here: the result could be very close to 1 */
+	for(i = 0; i < 110;  pr *= lambda/++i) {
+	    sum2 += pr;
 	    sum += pr * pchisq(x, f+2*i, lower_tail, FALSE);
-	return sum;
+	    if (sum2 >= 1-1e-15) break;
+	}
+	ans = sum/sum2;
+	return ans;
     }
 
 
@@ -104,7 +124,7 @@ pnchisq_raw(double x, double f, double theta,
 #endif
 
     if(f2 * DBL_EPSILON > 0.125 && /* very large f and x ~= f: probably needs */
-       fabs(t = x2 - f2) <         /* other algorithm anyway */
+       fabs(t = x2 - f2) <         /* another algorithm anyway */
        sqrt(DBL_EPSILON) * f2) {
 	/* evade cancellation error */
 	/* t = exp((1 - t)*(2 - t/(f2 + 1))) / sqrt(2*M_PI*(f2 + 1));*/
